use crate::{
    library::{user::UserManager, Library},
    pages::components::{htmx_link, video_element},
};
use maud::html;
use rocket::http::CookieJar;
use rocket::{
    form::Form,
    get,
    http::{ContentType, Cookie, Status},
    post,
    response::Redirect,
    FromForm, State,
};
use serde_json::json;

use super::{
    api_response,
    components::{render_page, video_element_wide, HTMX},
    vec_to_api,
};

#[get("/login")]
pub async fn login(mut htmx: HTMX, um: &State<UserManager>) -> (Status, (ContentType, String)) {
    let user = htmx.user(um).await;

    let content = html!(
        h2 { "Login" };
        form action="/login" method="POST" {
            input type="text" name="username" placeholder="Username" required;
            input type="password" name="password" placeholder="Password" required;
            input type="submit" value="Login";
        }
    );

    render_page(htmx, content, "Login", user).await
}

#[derive(FromForm)]
pub struct LoginForm {
    username: String,
    password: String,
}

#[post("/login", data = "<login_form>")]
pub async fn login_post(
    login_form: Form<LoginForm>,
    um: &State<UserManager>,
    cookies: &CookieJar<'_>,
) -> Option<Redirect> {
    let login_data = login_form.into_inner();

    let (session, _) = um.login(&login_data.username, &login_data.password).await?;

    let session_cookie = Cookie::build(("session_id", session.id.to_string()))
        .path("/") // Set the cookie path to the root so it’s available for the whole app
        .http_only(true) // Make the cookie HTTP only for security
        .max_age(rocket::time::Duration::days(7)) // Set the cookie expiration (7 days in this case)
        .build();

    cookies.add(session_cookie);

    Some(Redirect::to("/"))
}
